package ru.myitschool.work.ui.qr.result

import ru.myitschool.work.ui.qr.scan.QrScanDestination
import androidx.navigation.fragment.findNavController
import ru.myitschool.work.SessionManager
import ru.myitschool.work.api.OpenDoorRequest
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.lifecycle.lifecycleScope
import kotlinx.coroutines.launch
import retrofit2.Retrofit
import retrofit2.converter.gson.GsonConverterFactory
import ru.myitschool.work.R
import ru.myitschool.work.api.ApiService
import ru.myitschool.work.core.Constants
import ru.myitschool.work.databinding.FragmentQrScanResultBinding

class QrResult : Fragment(R.layout.fragment_qr_scan_result) {
    private lateinit var binding: FragmentQrScanResultBinding
    private lateinit var apiService: ApiService

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentQrScanResultBinding.inflate(inflater, container, false)
        apiService = Retrofit.Builder()
            .baseUrl(Constants.SERVER_ADDRESS)
            .addConverterFactory(GsonConverterFactory.create())
            .build()
            .create(ApiService::class.java)

        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val qrData = QrScanDestination.getDataIfExist(requireArguments())
        if (qrData != null) {
            sendRequestToServer(qrData)
        } else {
            binding.result.text = "Вход был отменён/Operation was cancelled"
        }

        binding.close.setOnClickListener {
            findNavController().popBackStack()
        }
    }

    private fun sendRequestToServer(qrData: String) {
        lifecycleScope.launch {
            try {
                // Проверяем, что userLogin не равен null
                val login = SessionManager.userLogin
                if (login != null) {
                    // Создаем объект OpenDoorRequest с логином и кодом
                    val openDoorRequest = OpenDoorRequest(login, qrData.toLong()) // Преобразуем qrData в Long, если это необходимо
                    val response = apiService.openDoor(openDoorRequest) // Теперь передаем только openDoorRequest
                    if (response.isSuccessful) {
                        binding.result.text = "Успешно/Success"
                    } else {
                        binding.result.text = "Что-то пошло не так/Something wrong"
                    }
                } else {
                    binding.result.text = "Пользователь не авторизован/Unauthorized user"
                }
            } catch (e: Exception) {
                binding.result.text = "Что-то пошло не так/Something wrong"
            }
        }
    }
}